# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from collibra_core.configuration import Configuration


class ExportComplexRelationsToCSVRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'complex_relation_type_id': 'str',
        'domain_id': 'str',
        'store_as_attachment': 'bool',
        'file_name': 'str',
        'include_header_row': 'bool',
        'support_roundtrip': 'bool',
        'remove_formatting': 'bool',
        'separator': 'str',
        'quote': 'str',
        'escape': 'str'
    }

    attribute_map = {
        'complex_relation_type_id': 'complexRelationTypeId',
        'domain_id': 'domainId',
        'store_as_attachment': 'storeAsAttachment',
        'file_name': 'fileName',
        'include_header_row': 'includeHeaderRow',
        'support_roundtrip': 'supportRoundtrip',
        'remove_formatting': 'removeFormatting',
        'separator': 'separator',
        'quote': 'quote',
        'escape': 'escape'
    }

    def __init__(self, complex_relation_type_id=None, domain_id=None, store_as_attachment=None, file_name=None, include_header_row=None, support_roundtrip=None, remove_formatting=None, separator=None, quote=None, escape=None, local_vars_configuration=None):  # noqa: E501
        """ExportComplexRelationsToCSVRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._complex_relation_type_id = None
        self._domain_id = None
        self._store_as_attachment = None
        self._file_name = None
        self._include_header_row = None
        self._support_roundtrip = None
        self._remove_formatting = None
        self._separator = None
        self._quote = None
        self._escape = None
        self.discriminator = None

        self.complex_relation_type_id = complex_relation_type_id
        if domain_id is not None:
            self.domain_id = domain_id
        if store_as_attachment is not None:
            self.store_as_attachment = store_as_attachment
        if file_name is not None:
            self.file_name = file_name
        if include_header_row is not None:
            self.include_header_row = include_header_row
        if support_roundtrip is not None:
            self.support_roundtrip = support_roundtrip
        if remove_formatting is not None:
            self.remove_formatting = remove_formatting
        if separator is not None:
            self.separator = separator
        if quote is not None:
            self.quote = quote
        if escape is not None:
            self.escape = escape

    @property
    def complex_relation_type_id(self):
        """Gets the complex_relation_type_id of this ExportComplexRelationsToCSVRequest.  # noqa: E501

        The Id of the ComplexRelationType for which the export will be executed.  # noqa: E501

        :return: The complex_relation_type_id of this ExportComplexRelationsToCSVRequest.  # noqa: E501
        :rtype: str
        """
        return self._complex_relation_type_id

    @complex_relation_type_id.setter
    def complex_relation_type_id(self, complex_relation_type_id):
        """Sets the complex_relation_type_id of this ExportComplexRelationsToCSVRequest.

        The Id of the ComplexRelationType for which the export will be executed.  # noqa: E501

        :param complex_relation_type_id: The complex_relation_type_id of this ExportComplexRelationsToCSVRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and complex_relation_type_id is None:  # noqa: E501
            raise ValueError("Invalid value for `complex_relation_type_id`, must not be `None`")  # noqa: E501

        self._complex_relation_type_id = complex_relation_type_id

    @property
    def domain_id(self):
        """Gets the domain_id of this ExportComplexRelationsToCSVRequest.  # noqa: E501

        The Id of the Domain to filter on (optional).  # noqa: E501

        :return: The domain_id of this ExportComplexRelationsToCSVRequest.  # noqa: E501
        :rtype: str
        """
        return self._domain_id

    @domain_id.setter
    def domain_id(self, domain_id):
        """Sets the domain_id of this ExportComplexRelationsToCSVRequest.

        The Id of the Domain to filter on (optional).  # noqa: E501

        :param domain_id: The domain_id of this ExportComplexRelationsToCSVRequest.  # noqa: E501
        :type: str
        """

        self._domain_id = domain_id

    @property
    def store_as_attachment(self):
        """Gets the store_as_attachment of this ExportComplexRelationsToCSVRequest.  # noqa: E501

        Sets if the export should be stored as an attachment (<code>true</code>) or not (<code>false</code>)<br/>of the provided {@link #domainId}.  # noqa: E501

        :return: The store_as_attachment of this ExportComplexRelationsToCSVRequest.  # noqa: E501
        :rtype: bool
        """
        return self._store_as_attachment

    @store_as_attachment.setter
    def store_as_attachment(self, store_as_attachment):
        """Sets the store_as_attachment of this ExportComplexRelationsToCSVRequest.

        Sets if the export should be stored as an attachment (<code>true</code>) or not (<code>false</code>)<br/>of the provided {@link #domainId}.  # noqa: E501

        :param store_as_attachment: The store_as_attachment of this ExportComplexRelationsToCSVRequest.  # noqa: E501
        :type: bool
        """

        self._store_as_attachment = store_as_attachment

    @property
    def file_name(self):
        """Gets the file_name of this ExportComplexRelationsToCSVRequest.  # noqa: E501

        The name of the file. (optional) if not provided a name is generated.  # noqa: E501

        :return: The file_name of this ExportComplexRelationsToCSVRequest.  # noqa: E501
        :rtype: str
        """
        return self._file_name

    @file_name.setter
    def file_name(self, file_name):
        """Sets the file_name of this ExportComplexRelationsToCSVRequest.

        The name of the file. (optional) if not provided a name is generated.  # noqa: E501

        :param file_name: The file_name of this ExportComplexRelationsToCSVRequest.  # noqa: E501
        :type: str
        """

        self._file_name = file_name

    @property
    def include_header_row(self):
        """Gets the include_header_row of this ExportComplexRelationsToCSVRequest.  # noqa: E501

        Set if the file will include a header (<code>true</code>) or not (<code>false</code>)<br/>Default value is <code>false</code>.  # noqa: E501

        :return: The include_header_row of this ExportComplexRelationsToCSVRequest.  # noqa: E501
        :rtype: bool
        """
        return self._include_header_row

    @include_header_row.setter
    def include_header_row(self, include_header_row):
        """Sets the include_header_row of this ExportComplexRelationsToCSVRequest.

        Set if the file will include a header (<code>true</code>) or not (<code>false</code>)<br/>Default value is <code>false</code>.  # noqa: E501

        :param include_header_row: The include_header_row of this ExportComplexRelationsToCSVRequest.  # noqa: E501
        :type: bool
        """

        self._include_header_row = include_header_row

    @property
    def support_roundtrip(self):
        """Gets the support_roundtrip of this ExportComplexRelationsToCSVRequest.  # noqa: E501

        Adds characteristics to support reimport (<code>true</code>) or not (<code>false</code>)<br/>Default value is <code>false</code>.  # noqa: E501

        :return: The support_roundtrip of this ExportComplexRelationsToCSVRequest.  # noqa: E501
        :rtype: bool
        """
        return self._support_roundtrip

    @support_roundtrip.setter
    def support_roundtrip(self, support_roundtrip):
        """Sets the support_roundtrip of this ExportComplexRelationsToCSVRequest.

        Adds characteristics to support reimport (<code>true</code>) or not (<code>false</code>)<br/>Default value is <code>false</code>.  # noqa: E501

        :param support_roundtrip: The support_roundtrip of this ExportComplexRelationsToCSVRequest.  # noqa: E501
        :type: bool
        """

        self._support_roundtrip = support_roundtrip

    @property
    def remove_formatting(self):
        """Gets the remove_formatting of this ExportComplexRelationsToCSVRequest.  # noqa: E501

        Remove text formatting (<code>true</code>) or not (<code>false</code>)<br/>Default value is <code>false</code>.  # noqa: E501

        :return: The remove_formatting of this ExportComplexRelationsToCSVRequest.  # noqa: E501
        :rtype: bool
        """
        return self._remove_formatting

    @remove_formatting.setter
    def remove_formatting(self, remove_formatting):
        """Sets the remove_formatting of this ExportComplexRelationsToCSVRequest.

        Remove text formatting (<code>true</code>) or not (<code>false</code>)<br/>Default value is <code>false</code>.  # noqa: E501

        :param remove_formatting: The remove_formatting of this ExportComplexRelationsToCSVRequest.  # noqa: E501
        :type: bool
        """

        self._remove_formatting = remove_formatting

    @property
    def separator(self):
        """Gets the separator of this ExportComplexRelationsToCSVRequest.  # noqa: E501

        The delimiter character used to separate entries.<br/>If not provided default value <code>';'</code> is used.  # noqa: E501

        :return: The separator of this ExportComplexRelationsToCSVRequest.  # noqa: E501
        :rtype: str
        """
        return self._separator

    @separator.setter
    def separator(self, separator):
        """Sets the separator of this ExportComplexRelationsToCSVRequest.

        The delimiter character used to separate entries.<br/>If not provided default value <code>';'</code> is used.  # noqa: E501

        :param separator: The separator of this ExportComplexRelationsToCSVRequest.  # noqa: E501
        :type: str
        """

        self._separator = separator

    @property
    def quote(self):
        """Gets the quote of this ExportComplexRelationsToCSVRequest.  # noqa: E501

        The delimiter character used for quoted entries.<br/>If not provided default value <code>'\\\"'</code> is used.  # noqa: E501

        :return: The quote of this ExportComplexRelationsToCSVRequest.  # noqa: E501
        :rtype: str
        """
        return self._quote

    @quote.setter
    def quote(self, quote):
        """Sets the quote of this ExportComplexRelationsToCSVRequest.

        The delimiter character used for quoted entries.<br/>If not provided default value <code>'\\\"'</code> is used.  # noqa: E501

        :param quote: The quote of this ExportComplexRelationsToCSVRequest.  # noqa: E501
        :type: str
        """

        self._quote = quote

    @property
    def escape(self):
        """Gets the escape of this ExportComplexRelationsToCSVRequest.  # noqa: E501

        The delimiter character used to escape separator or quote character.<br/>If not provided default value <code>'\\\\'</code> is used.  # noqa: E501

        :return: The escape of this ExportComplexRelationsToCSVRequest.  # noqa: E501
        :rtype: str
        """
        return self._escape

    @escape.setter
    def escape(self, escape):
        """Sets the escape of this ExportComplexRelationsToCSVRequest.

        The delimiter character used to escape separator or quote character.<br/>If not provided default value <code>'\\\\'</code> is used.  # noqa: E501

        :param escape: The escape of this ExportComplexRelationsToCSVRequest.  # noqa: E501
        :type: str
        """

        self._escape = escape

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ExportComplexRelationsToCSVRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ExportComplexRelationsToCSVRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import collibra_core
from collibra_core.models.job_paged_response import JobPagedResponse  # noqa: E501
from collibra_core.rest import ApiException

class TestJobPagedResponse(unittest.TestCase):
    """JobPagedResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test JobPagedResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = collibra_core.models.job_paged_response.JobPagedResponse()  # noqa: E501
        if include_optional :
            return JobPagedResponse(
                total = 1000, 
                offset = 10, 
                limit = 100, 
                results = [
                    collibra_core.models.job.Job(
                        id = '0', 
                        created_by = '4d250cc5-e583-4640-9874-b93d82c7a6cb', 
                        created_on = 1475503010320, 
                        last_modified_by = 'a073ff90-e7bc-4b35-ba90-c4d475f642fe', 
                        last_modified_on = 1476703764163, 
                        system = True, 
                        resource_type = 'View', 
                        name = 'Test name', 
                        type = 'IMPORT', 
                        user_id = '0', 
                        visibility = 56, 
                        progress_percentage = 50, 
                        cancelable = True, 
                        start_date = 1488016800, 
                        end_date = 1488021800, 
                        state = 'COMPLETED', 
                        result = 'SUCCESS', 
                        message = 'Import finished in 12s.', )
                    ]
            )
        else :
            return JobPagedResponse(
        )

    def testJobPagedResponse(self):
        """Test JobPagedResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from collibra_core.api_client import ApiClient
from collibra_core.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class AuthenticationSessionsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def current_session(self, **kwargs):  # noqa: E501
        """Get session  # noqa: E501

        Gets current session (checks if user is logged in).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.current_session(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] include: Specify additional objects to include in the session response. Supports 'csrfToken' and 'user'. Multiple inclusions may be specified using additional 'include' query parameters or by comma-separated list.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.current_session_with_http_info(**kwargs)  # noqa: E501

    def current_session_with_http_info(self, **kwargs):  # noqa: E501
        """Get session  # noqa: E501

        Gets current session (checks if user is logged in).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.current_session_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] include: Specify additional objects to include in the session response. Supports 'csrfToken' and 'user'. Multiple inclusions may be specified using additional 'include' query parameters or by comma-separated list.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'include'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method current_session" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'include' in local_var_params and local_var_params['include'] is not None:  # noqa: E501
            query_params.append(('include', local_var_params['include']))  # noqa: E501
            collection_formats['include'] = 'multi'  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/auth/sessions/current', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def heartbeat(self, **kwargs):  # noqa: E501
        """Checks if the user session is active  # noqa: E501

        Returns 200 if user session is active and 401 if the session is expired or doesn't exist  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.heartbeat(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.heartbeat_with_http_info(**kwargs)  # noqa: E501

    def heartbeat_with_http_info(self, **kwargs):  # noqa: E501
        """Checks if the user session is active  # noqa: E501

        Returns 200 if user session is active and 401 if the session is expired or doesn't exist  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.heartbeat_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method heartbeat" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/auth/sessions/heartbeat', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def login(self, **kwargs):  # noqa: E501
        """Login  # noqa: E501

        Authenticates a user and creates a new session on the server. Once the user is authenticated then the returned session id can be used to access DGC REST Api in subsequent requests. The method additionally returns the JSESSIONID cookie in a <code>Set-Cookie</code> header. If user already has an open session then this session will be terminated.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.login(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param LoginRequest login_request:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: DGCSession
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.login_with_http_info(**kwargs)  # noqa: E501

    def login_with_http_info(self, **kwargs):  # noqa: E501
        """Login  # noqa: E501

        Authenticates a user and creates a new session on the server. Once the user is authenticated then the returned session id can be used to access DGC REST Api in subsequent requests. The method additionally returns the JSESSIONID cookie in a <code>Set-Cookie</code> header. If user already has an open session then this session will be terminated.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.login_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param LoginRequest login_request:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(DGCSession, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'login_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method login" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'login_request' in local_var_params:
            body_params = local_var_params['login_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/auth/sessions', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DGCSession',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def logout(self, **kwargs):  # noqa: E501
        """Logout  # noqa: E501

        Logs current user out and destroys the active session.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.logout(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.logout_with_http_info(**kwargs)  # noqa: E501

    def logout_with_http_info(self, **kwargs):  # noqa: E501
        """Logout  # noqa: E501

        Logs current user out and destroys the active session.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.logout_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method logout" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/auth/sessions/current', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import collibra_core
from collibra_core.api.assets_api import AssetsApi  # noqa: E501
from collibra_core.rest import ApiException


class TestAssetsApi(unittest.TestCase):
    """AssetsApi unit test stubs"""

    def setUp(self):
        self.api = collibra_core.api.assets_api.AssetsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_asset(self):
        """Test case for add_asset

        Add asset  # noqa: E501
        """
        pass

    def test_add_assets(self):
        """Test case for add_assets

        Add multiple assets  # noqa: E501
        """
        pass

    def test_add_tags_to_asset(self):
        """Test case for add_tags_to_asset

        Add tags  # noqa: E501
        """
        pass

    def test_change_asset(self):
        """Test case for change_asset

        Change asset  # noqa: E501
        """
        pass

    def test_change_assets(self):
        """Test case for change_assets

        Change multiple assets  # noqa: E501
        """
        pass

    def test_find_assets(self):
        """Test case for find_assets

        Find assets  # noqa: E501
        """
        pass

    def test_get_asset(self):
        """Test case for get_asset

        Get asset  # noqa: E501
        """
        pass

    def test_get_asset_breadcrumb(self):
        """Test case for get_asset_breadcrumb

        Get asset breadcrumb  # noqa: E501
        """
        pass

    def test_get_asset_tags(self):
        """Test case for get_asset_tags

        Get asset tags  # noqa: E501
        """
        pass

    def test_remove_asset(self):
        """Test case for remove_asset

        Remove asset  # noqa: E501
        """
        pass

    def test_remove_assets(self):
        """Test case for remove_assets

        Remove assets  # noqa: E501
        """
        pass

    def test_remove_tags_from_asset(self):
        """Test case for remove_tags_from_asset

        Remove tags  # noqa: E501
        """
        pass

    def test_set_asset_attributes(self):
        """Test case for set_asset_attributes

        Set asset attributes  # noqa: E501
        """
        pass

    def test_set_asset_relations(self):
        """Test case for set_asset_relations

        Set asset relations  # noqa: E501
        """
        pass

    def test_set_asset_responsibilities(self):
        """Test case for set_asset_responsibilities

        Set asset responsibilities  # noqa: E501
        """
        pass

    def test_set_tags_for_asset(self):
        """Test case for set_tags_for_asset

        Set asset tags  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from collibra_core.api.activities_api import ActivitiesApi
from collibra_core.api.application_api import ApplicationApi
from collibra_core.api.asset_types_api import AssetTypesApi
from collibra_core.api.assets_api import AssetsApi
from collibra_core.api.assignments_api import AssignmentsApi
from collibra_core.api.attachments_api import AttachmentsApi
from collibra_core.api.attribute_types_api import AttributeTypesApi
from collibra_core.api.attributes_api import AttributesApi
from collibra_core.api.authentication__sessions_api import AuthenticationSessionsApi
from collibra_core.api.comments_api import CommentsApi
from collibra_core.api.communities_api import CommunitiesApi
from collibra_core.api.complex_relation_types_api import ComplexRelationTypesApi
from collibra_core.api.complex_relations_api import ComplexRelationsApi
from collibra_core.api.data_quality_rules_api import DataQualityRulesApi
from collibra_core.api.diagram_pictures_api import DiagramPicturesApi
from collibra_core.api.domain_types_api import DomainTypesApi
from collibra_core.api.domains_api import DomainsApi
from collibra_core.api.files_api import FilesApi
from collibra_core.api.issues_api import IssuesApi
from collibra_core.api.jdbc_driver_api import JDBCDriverApi
from collibra_core.api.jobs_api import JobsApi
from collibra_core.api.mappings_api import MappingsApi
from collibra_core.api.navigation_statistics_api import NavigationStatisticsApi
from collibra_core.api.output_module_api import OutputModuleApi
from collibra_core.api.ratings_api import RatingsApi
from collibra_core.api.relation_types_api import RelationTypesApi
from collibra_core.api.relations_api import RelationsApi
from collibra_core.api.reporting_api import ReportingApi
from collibra_core.api.responsibilities_api import ResponsibilitiesApi
from collibra_core.api.roles_api import RolesApi
from collibra_core.api.saml_api import SAMLApi
from collibra_core.api.scopes_api import ScopesApi
from collibra_core.api.statuses_api import StatusesApi
from collibra_core.api.tags_api import TagsApi
from collibra_core.api.user_groups_api import UserGroupsApi
from collibra_core.api.users_api import UsersApi
from collibra_core.api.validation_api import ValidationApi
from collibra_core.api.view_permissions_api import ViewPermissionsApi
from collibra_core.api.workflow_definitions_api import WorkflowDefinitionsApi
from collibra_core.api.workflow_instances_api import WorkflowInstancesApi
from collibra_core.api.workflow_tasks_api import WorkflowTasksApi



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from collibra_core.api_client import ApiClient
from collibra_core.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class AttributesApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def add_attribute(self, **kwargs):  # noqa: E501
        """Add attribute  # noqa: E501

        Adds a new attribute to an asset.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_attribute(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AddAttributeRequest add_attribute_request: the properties of the attribute to be added
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Attribute
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.add_attribute_with_http_info(**kwargs)  # noqa: E501

    def add_attribute_with_http_info(self, **kwargs):  # noqa: E501
        """Add attribute  # noqa: E501

        Adds a new attribute to an asset.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_attribute_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AddAttributeRequest add_attribute_request: the properties of the attribute to be added
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Attribute, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'add_attribute_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_attribute" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'add_attribute_request' in local_var_params:
            body_params = local_var_params['add_attribute_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/attributes', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Attribute',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def add_attributes(self, **kwargs):  # noqa: E501
        """Add attributes  # noqa: E501

        Adds multiple attributes.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_attributes(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[AddAttributeRequest] add_attribute_request: the list of the properties of the attributes to be added
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[Attribute]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.add_attributes_with_http_info(**kwargs)  # noqa: E501

    def add_attributes_with_http_info(self, **kwargs):  # noqa: E501
        """Add attributes  # noqa: E501

        Adds multiple attributes.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_attributes_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[AddAttributeRequest] add_attribute_request: the list of the properties of the attributes to be added
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[Attribute], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'add_attribute_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_attributes" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'add_attribute_request' in local_var_params:
            body_params = local_var_params['add_attribute_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/attributes/bulk', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Attribute]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def change_attribute(self, attribute_id, **kwargs):  # noqa: E501
        """Change attribute  # noqa: E501

        Changes the attribute with the information that is present in the request. Only properties that are specified in this request and have not <code>null</code> values are updated. All other properties are ignored.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_attribute(attribute_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str attribute_id: the id of the attribute (required)
        :param ChangeAttributeRequest change_attribute_request: the properties of the attribute to be changed
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Attribute
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.change_attribute_with_http_info(attribute_id, **kwargs)  # noqa: E501

    def change_attribute_with_http_info(self, attribute_id, **kwargs):  # noqa: E501
        """Change attribute  # noqa: E501

        Changes the attribute with the information that is present in the request. Only properties that are specified in this request and have not <code>null</code> values are updated. All other properties are ignored.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_attribute_with_http_info(attribute_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str attribute_id: the id of the attribute (required)
        :param ChangeAttributeRequest change_attribute_request: the properties of the attribute to be changed
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Attribute, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'attribute_id',
            'change_attribute_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method change_attribute" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'attribute_id' is set
        if self.api_client.client_side_validation and ('attribute_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['attribute_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `attribute_id` when calling `change_attribute`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'attribute_id' in local_var_params:
            path_params['attributeId'] = local_var_params['attribute_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'change_attribute_request' in local_var_params:
            body_params = local_var_params['change_attribute_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/attributes/{attributeId}', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Attribute',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def change_attributes(self, **kwargs):  # noqa: E501
        """Change attributes  # noqa: E501

        Changes multiple attributes with the information that is present in the request. Only properties that are specified in this request and have not <code>null</code> values are updated. All other properties are ignored.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_attributes(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[ChangeAttributeRequest] change_attribute_request: the list of properties of the attributes to be changed
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Attribute
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.change_attributes_with_http_info(**kwargs)  # noqa: E501

    def change_attributes_with_http_info(self, **kwargs):  # noqa: E501
        """Change attributes  # noqa: E501

        Changes multiple attributes with the information that is present in the request. Only properties that are specified in this request and have not <code>null</code> values are updated. All other properties are ignored.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_attributes_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[ChangeAttributeRequest] change_attribute_request: the list of properties of the attributes to be changed
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Attribute, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'change_attribute_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method change_attributes" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'change_attribute_request' in local_var_params:
            body_params = local_var_params['change_attribute_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/attributes/bulk', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Attribute',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def find_attributes(self, **kwargs):  # noqa: E501
        """Find attributes  # noqa: E501

        Returns attributes matching the given search criteria. Only parameters that are specified in this request and have not <code>null</code> values are used for filtering. All other parameters are ignored. The returned attributes satisfy all constraints that are specified in this search criteria. By default a result containing 1000 attributes is returned.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_attributes(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int offset: The first result to retrieve. If not set (offset = <code>0</code>), results will be retrieved starting from row <code>0</code>. Cursor should be preferred over offset for better performance and stable results. It is forbidden to use both in the same request.
        :param int limit: The maximum number of results to retrieve. If not set (limit = <code>0</code>), the default limit will be used.
        :param int count_limit: Allows to limit the number of elements that will be counted. -1 will count everything and 0 will cause the count to be skipped. For cursor pagination this parameter is ignored and count is skipped.
        :param str cursor: Cursor for current page of results. To retrieve first page with cursor pagination you need to pass this parameter with empty value. For next pages the value must be taken from response (<code>nextCursor</code> property).
        :param list[str] type_ids: The list of IDs of the attribute types the found attributes should have.
        :param str asset_id: The ID of the asset to find the attributes in.
        :param str sort_order: The sorting order.
        :param str sort_field: The field on which the results are sorted.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: AttributePagedResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.find_attributes_with_http_info(**kwargs)  # noqa: E501

    def find_attributes_with_http_info(self, **kwargs):  # noqa: E501
        """Find attributes  # noqa: E501

        Returns attributes matching the given search criteria. Only parameters that are specified in this request and have not <code>null</code> values are used for filtering. All other parameters are ignored. The returned attributes satisfy all constraints that are specified in this search criteria. By default a result containing 1000 attributes is returned.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_attributes_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int offset: The first result to retrieve. If not set (offset = <code>0</code>), results will be retrieved starting from row <code>0</code>. Cursor should be preferred over offset for better performance and stable results. It is forbidden to use both in the same request.
        :param int limit: The maximum number of results to retrieve. If not set (limit = <code>0</code>), the default limit will be used.
        :param int count_limit: Allows to limit the number of elements that will be counted. -1 will count everything and 0 will cause the count to be skipped. For cursor pagination this parameter is ignored and count is skipped.
        :param str cursor: Cursor for current page of results. To retrieve first page with cursor pagination you need to pass this parameter with empty value. For next pages the value must be taken from response (<code>nextCursor</code> property).
        :param list[str] type_ids: The list of IDs of the attribute types the found attributes should have.
        :param str asset_id: The ID of the asset to find the attributes in.
        :param str sort_order: The sorting order.
        :param str sort_field: The field on which the results are sorted.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(AttributePagedResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'offset',
            'limit',
            'count_limit',
            'cursor',
            'type_ids',
            'asset_id',
            'sort_order',
            'sort_field'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method find_attributes" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'offset' in local_var_params and local_var_params['offset'] is not None:  # noqa: E501
            query_params.append(('offset', local_var_params['offset']))  # noqa: E501
        if 'limit' in local_var_params and local_var_params['limit'] is not None:  # noqa: E501
            query_params.append(('limit', local_var_params['limit']))  # noqa: E501
        if 'count_limit' in local_var_params and local_var_params['count_limit'] is not None:  # noqa: E501
            query_params.append(('countLimit', local_var_params['count_limit']))  # noqa: E501
        if 'cursor' in local_var_params and local_var_params['cursor'] is not None:  # noqa: E501
            query_params.append(('cursor', local_var_params['cursor']))  # noqa: E501
        if 'type_ids' in local_var_params and local_var_params['type_ids'] is not None:  # noqa: E501
            query_params.append(('typeIds', local_var_params['type_ids']))  # noqa: E501
            collection_formats['typeIds'] = 'multi'  # noqa: E501
        if 'asset_id' in local_var_params and local_var_params['asset_id'] is not None:  # noqa: E501
            query_params.append(('assetId', local_var_params['asset_id']))  # noqa: E501
        if 'sort_order' in local_var_params and local_var_params['sort_order'] is not None:  # noqa: E501
            query_params.append(('sortOrder', local_var_params['sort_order']))  # noqa: E501
        if 'sort_field' in local_var_params and local_var_params['sort_field'] is not None:  # noqa: E501
            query_params.append(('sortField', local_var_params['sort_field']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/attributes', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AttributePagedResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_attribute(self, attribute_id, **kwargs):  # noqa: E501
        """Get attribute  # noqa: E501

        Returns the attribute identified by given id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_attribute(attribute_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str attribute_id: the id of the attribute (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Attribute
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_attribute_with_http_info(attribute_id, **kwargs)  # noqa: E501

    def get_attribute_with_http_info(self, attribute_id, **kwargs):  # noqa: E501
        """Get attribute  # noqa: E501

        Returns the attribute identified by given id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_attribute_with_http_info(attribute_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str attribute_id: the id of the attribute (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Attribute, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'attribute_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_attribute" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'attribute_id' is set
        if self.api_client.client_side_validation and ('attribute_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['attribute_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `attribute_id` when calling `get_attribute`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'attribute_id' in local_var_params:
            path_params['attributeId'] = local_var_params['attribute_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/attributes/{attributeId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Attribute',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remove_attribute(self, attribute_id, **kwargs):  # noqa: E501
        """Remove attribute  # noqa: E501

        Removes the attribute identified by given id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_attribute(attribute_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str attribute_id: the id of the attribute (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.remove_attribute_with_http_info(attribute_id, **kwargs)  # noqa: E501

    def remove_attribute_with_http_info(self, attribute_id, **kwargs):  # noqa: E501
        """Remove attribute  # noqa: E501

        Removes the attribute identified by given id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_attribute_with_http_info(attribute_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str attribute_id: the id of the attribute (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'attribute_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_attribute" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'attribute_id' is set
        if self.api_client.client_side_validation and ('attribute_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['attribute_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `attribute_id` when calling `remove_attribute`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'attribute_id' in local_var_params:
            path_params['attributeId'] = local_var_params['attribute_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/attributes/{attributeId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remove_attributes(self, **kwargs):  # noqa: E501
        """Remove attributes  # noqa: E501

        Removes the attributes identified by given ids.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_attributes(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] request_body: the ids of the attributes to remove
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.remove_attributes_with_http_info(**kwargs)  # noqa: E501

    def remove_attributes_with_http_info(self, **kwargs):  # noqa: E501
        """Remove attributes  # noqa: E501

        Removes the attributes identified by given ids.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_attributes_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] request_body: the ids of the attributes to remove
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'request_body'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_attributes" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'request_body' in local_var_params:
            body_params = local_var_params['request_body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/attributes/bulk', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

# flake8: noqa

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from collibra_core.api.activities_api import ActivitiesApi
from collibra_core.api.application_api import ApplicationApi
from collibra_core.api.asset_types_api import AssetTypesApi
from collibra_core.api.assets_api import AssetsApi
from collibra_core.api.assignments_api import AssignmentsApi
from collibra_core.api.attachments_api import AttachmentsApi
from collibra_core.api.attribute_types_api import AttributeTypesApi
from collibra_core.api.attributes_api import AttributesApi
from collibra_core.api.authentication__sessions_api import AuthenticationSessionsApi
from collibra_core.api.comments_api import CommentsApi
from collibra_core.api.communities_api import CommunitiesApi
from collibra_core.api.complex_relation_types_api import ComplexRelationTypesApi
from collibra_core.api.complex_relations_api import ComplexRelationsApi
from collibra_core.api.data_quality_rules_api import DataQualityRulesApi
from collibra_core.api.diagram_pictures_api import DiagramPicturesApi
from collibra_core.api.domain_types_api import DomainTypesApi
from collibra_core.api.domains_api import DomainsApi
from collibra_core.api.files_api import FilesApi
from collibra_core.api.issues_api import IssuesApi
from collibra_core.api.jdbc_driver_api import JDBCDriverApi
from collibra_core.api.jobs_api import JobsApi
from collibra_core.api.mappings_api import MappingsApi
from collibra_core.api.navigation_statistics_api import NavigationStatisticsApi
from collibra_core.api.output_module_api import OutputModuleApi
from collibra_core.api.ratings_api import RatingsApi
from collibra_core.api.relation_types_api import RelationTypesApi
from collibra_core.api.relations_api import RelationsApi
from collibra_core.api.reporting_api import ReportingApi
from collibra_core.api.responsibilities_api import ResponsibilitiesApi
from collibra_core.api.roles_api import RolesApi
from collibra_core.api.saml_api import SAMLApi
from collibra_core.api.scopes_api import ScopesApi
from collibra_core.api.statuses_api import StatusesApi
from collibra_core.api.tags_api import TagsApi
from collibra_core.api.user_groups_api import UserGroupsApi
from collibra_core.api.users_api import UsersApi
from collibra_core.api.validation_api import ValidationApi
from collibra_core.api.view_permissions_api import ViewPermissionsApi
from collibra_core.api.workflow_definitions_api import WorkflowDefinitionsApi
from collibra_core.api.workflow_instances_api import WorkflowInstancesApi
from collibra_core.api.workflow_tasks_api import WorkflowTasksApi

# import ApiClient
from collibra_core.api_client import ApiClient
from collibra_core.configuration import Configuration
from collibra_core.exceptions import OpenApiException
from collibra_core.exceptions import ApiTypeError
from collibra_core.exceptions import ApiValueError
from collibra_core.exceptions import ApiKeyError
from collibra_core.exceptions import ApiException
# import models into sdk package
from collibra_core.models.activity_impl import ActivityImpl
from collibra_core.models.activity_paged_response import ActivityPagedResponse
from collibra_core.models.add_asset_request import AddAssetRequest
from collibra_core.models.add_asset_tags_request import AddAssetTagsRequest
from collibra_core.models.add_asset_type_assignment_rule_request import AddAssetTypeAssignmentRuleRequest
from collibra_core.models.add_asset_type_request import AddAssetTypeRequest
from collibra_core.models.add_assignment_request import AddAssignmentRequest
from collibra_core.models.add_attribute_request import AddAttributeRequest
from collibra_core.models.add_attribute_type_request import AddAttributeTypeRequest
from collibra_core.models.add_comment_request import AddCommentRequest
from collibra_core.models.add_community_request import AddCommunityRequest
from collibra_core.models.add_complex_relation_request import AddComplexRelationRequest
from collibra_core.models.add_complex_relation_type_request import AddComplexRelationTypeRequest
from collibra_core.models.add_data_quality_rule_request import AddDataQualityRuleRequest
from collibra_core.models.add_diagram_picture_request import AddDiagramPictureRequest
from collibra_core.models.add_domain_request import AddDomainRequest
from collibra_core.models.add_domain_type_assignment_rule_request import AddDomainTypeAssignmentRuleRequest
from collibra_core.models.add_domain_type_request import AddDomainTypeRequest
from collibra_core.models.add_issue_request import AddIssueRequest
from collibra_core.models.add_mapping_request import AddMappingRequest
from collibra_core.models.add_rating_request import AddRatingRequest
from collibra_core.models.add_relation_request import AddRelationRequest
from collibra_core.models.add_relation_type_request import AddRelationTypeRequest
from collibra_core.models.add_responsibility_request import AddResponsibilityRequest
from collibra_core.models.add_role_request import AddRoleRequest
from collibra_core.models.add_scope_request import AddScopeRequest
from collibra_core.models.add_status_request import AddStatusRequest
from collibra_core.models.add_user_group_request import AddUserGroupRequest
from collibra_core.models.add_user_request import AddUserRequest
from collibra_core.models.add_user_to_user_groups_request import AddUserToUserGroupsRequest
from collibra_core.models.add_users_to_user_group_request import AddUsersToUserGroupRequest
from collibra_core.models.add_view_permission_request import AddViewPermissionRequest
from collibra_core.models.address import Address
from collibra_core.models.application_info import ApplicationInfo
from collibra_core.models.application_version_impl import ApplicationVersionImpl
from collibra_core.models.articulation_rule_impl import ArticulationRuleImpl
from collibra_core.models.articulation_rule_request import ArticulationRuleRequest
from collibra_core.models.asset_assignment_rule_impl import AssetAssignmentRuleImpl
from collibra_core.models.asset_impl import AssetImpl
from collibra_core.models.asset_paged_response import AssetPagedResponse
from collibra_core.models.asset_reference_impl import AssetReferenceImpl
from collibra_core.models.asset_type_impl import AssetTypeImpl
from collibra_core.models.asset_type_paged_response import AssetTypePagedResponse
from collibra_core.models.assigned_attribute_type import AssignedAttributeType
from collibra_core.models.assigned_attribute_type_all_of import AssignedAttributeTypeAllOf
from collibra_core.models.assigned_characteristic_type import AssignedCharacteristicType
from collibra_core.models.assigned_complex_relation_type import AssignedComplexRelationType
from collibra_core.models.assigned_complex_relation_type_all_of import AssignedComplexRelationTypeAllOf
from collibra_core.models.assigned_relation_type import AssignedRelationType
from collibra_core.models.assigned_relation_type_all_of import AssignedRelationTypeAllOf
from collibra_core.models.assignment_impl import AssignmentImpl
from collibra_core.models.attachment_impl import AttachmentImpl
from collibra_core.models.attachment_paged_response import AttachmentPagedResponse
from collibra_core.models.attribute import Attribute
from collibra_core.models.attribute_paged_response import AttributePagedResponse
from collibra_core.models.attribute_type import AttributeType
from collibra_core.models.attribute_type_paged_response import AttributeTypePagedResponse
from collibra_core.models.attribute_value import AttributeValue
from collibra_core.models.boolean_attribute import BooleanAttribute
from collibra_core.models.boolean_attribute_all_of import BooleanAttributeAllOf
from collibra_core.models.boolean_attribute_type import BooleanAttributeType
from collibra_core.models.boolean_attribute_type_all_of import BooleanAttributeTypeAllOf
from collibra_core.models.cancel_job_request import CancelJobRequest
from collibra_core.models.change_asset_request import ChangeAssetRequest
from collibra_core.models.change_asset_type_assignment_rule_request import ChangeAssetTypeAssignmentRuleRequest
from collibra_core.models.change_asset_type_request import ChangeAssetTypeRequest
from collibra_core.models.change_assignment_request import ChangeAssignmentRequest
from collibra_core.models.change_attribute_request import ChangeAttributeRequest
from collibra_core.models.change_attribute_type_request import ChangeAttributeTypeRequest
from collibra_core.models.change_comment_request import ChangeCommentRequest
from collibra_core.models.change_community_request import ChangeCommunityRequest
from collibra_core.models.change_complex_relation_request import ChangeComplexRelationRequest
from collibra_core.models.change_complex_relation_type_request import ChangeComplexRelationTypeRequest
from collibra_core.models.change_data_quality_rule_request import ChangeDataQualityRuleRequest
from collibra_core.models.change_domain_request import ChangeDomainRequest
from collibra_core.models.change_domain_type_assignment_rule_request import ChangeDomainTypeAssignmentRuleRequest
from collibra_core.models.change_domain_type_request import ChangeDomainTypeRequest
from collibra_core.models.change_mapping_by_external_entity_request import ChangeMappingByExternalEntityRequest
from collibra_core.models.change_mapping_by_mapped_resource_request import ChangeMappingByMappedResourceRequest
from collibra_core.models.change_mapping_request import ChangeMappingRequest
from collibra_core.models.change_rating_request import ChangeRatingRequest
from collibra_core.models.change_relation_request import ChangeRelationRequest
from collibra_core.models.change_relation_type_request import ChangeRelationTypeRequest
from collibra_core.models.change_role_request import ChangeRoleRequest
from collibra_core.models.change_scope_request import ChangeScopeRequest
from collibra_core.models.change_status_request import ChangeStatusRequest
from collibra_core.models.change_tag_request import ChangeTagRequest
from collibra_core.models.change_user_avatar_request import ChangeUserAvatarRequest
from collibra_core.models.change_user_group_request import ChangeUserGroupRequest
from collibra_core.models.change_user_request import ChangeUserRequest
from collibra_core.models.change_workflow_definition_request import ChangeWorkflowDefinitionRequest
from collibra_core.models.characteristic_type_assignment_reference import CharacteristicTypeAssignmentReference
from collibra_core.models.comment import Comment
from collibra_core.models.comment_paged_response import CommentPagedResponse
from collibra_core.models.community_impl import CommunityImpl
from collibra_core.models.community_paged_response import CommunityPagedResponse
from collibra_core.models.complete_workflow_tasks_request import CompleteWorkflowTasksRequest
from collibra_core.models.complex_relation_attribute_type_impl import ComplexRelationAttributeTypeImpl
from collibra_core.models.complex_relation_attribute_type_request import ComplexRelationAttributeTypeRequest
from collibra_core.models.complex_relation_impl import ComplexRelationImpl
from collibra_core.models.complex_relation_leg_impl import ComplexRelationLegImpl
from collibra_core.models.complex_relation_leg_request import ComplexRelationLegRequest
from collibra_core.models.complex_relation_leg_type_impl import ComplexRelationLegTypeImpl
from collibra_core.models.complex_relation_leg_type_request import ComplexRelationLegTypeRequest
from collibra_core.models.complex_relation_type_impl import ComplexRelationTypeImpl
from collibra_core.models.complex_relation_type_paged_response import ComplexRelationTypePagedResponse
from collibra_core.models.connection_string_parameter import ConnectionStringParameter
from collibra_core.models.cursor_paged_response_asset import CursorPagedResponseAsset
from collibra_core.models.cursor_paged_response_attribute import CursorPagedResponseAttribute
from collibra_core.models.cursor_paged_response_community import CursorPagedResponseCommunity
from collibra_core.models.cursor_paged_response_complex_relation import CursorPagedResponseComplexRelation
from collibra_core.models.cursor_paged_response_domain import CursorPagedResponseDomain
from collibra_core.models.cursor_paged_response_relation import CursorPagedResponseRelation
from collibra_core.models.dgc_session import DGCSession
from collibra_core.models.data_quality_metric_impl import DataQualityMetricImpl
from collibra_core.models.data_quality_metric_request import DataQualityMetricRequest
from collibra_core.models.data_quality_rule_impl import DataQualityRuleImpl
from collibra_core.models.data_quality_rule_paged_response import DataQualityRulePagedResponse
from collibra_core.models.date_attribute import DateAttribute
from collibra_core.models.date_attribute_all_of import DateAttributeAllOf
from collibra_core.models.date_attribute_type import DateAttributeType
from collibra_core.models.domain_impl import DomainImpl
from collibra_core.models.domain_paged_response import DomainPagedResponse
from collibra_core.models.domain_type_impl import DomainTypeImpl
from collibra_core.models.domain_type_paged_response import DomainTypePagedResponse
from collibra_core.models.dropdown_value import DropdownValue
from collibra_core.models.email import Email
from collibra_core.models.export_complex_relations_to_csv_request import ExportComplexRelationsToCSVRequest
from collibra_core.models.export_complex_relations_to_excel_request import ExportComplexRelationsToExcelRequest
from collibra_core.models.file_info_impl import FileInfoImpl
from collibra_core.models.file_reference_impl import FileReferenceImpl
from collibra_core.models.file_upload import FileUpload
from collibra_core.models.form_property import FormProperty
from collibra_core.models.inline_object import InlineObject
from collibra_core.models.inline_object1 import InlineObject1
from collibra_core.models.inline_object2 import InlineObject2
from collibra_core.models.instant_messaging_account import InstantMessagingAccount
from collibra_core.models.jdbc_driver import JdbcDriver
from collibra_core.models.jdbc_driver_file import JdbcDriverFile
from collibra_core.models.jdbc_driver_paged_response import JdbcDriverPagedResponse
from collibra_core.models.job import Job
from collibra_core.models.job_paged_response import JobPagedResponse
from collibra_core.models.login_request import LoginRequest
from collibra_core.models.mapping import Mapping
from collibra_core.models.mapping_paged_response import MappingPagedResponse
from collibra_core.models.merge_tags_request import MergeTagsRequest
from collibra_core.models.message_event_received_request import MessageEventReceivedRequest
from collibra_core.models.multi_value_list_attribute import MultiValueListAttribute
from collibra_core.models.multi_value_list_attribute_all_of import MultiValueListAttributeAllOf
from collibra_core.models.multi_value_list_attribute_type import MultiValueListAttributeType
from collibra_core.models.multi_value_list_attribute_type_all_of import MultiValueListAttributeTypeAllOf
from collibra_core.models.named_described_resource_reference import NamedDescribedResourceReference
from collibra_core.models.named_described_workflow_start_event_type import NamedDescribedWorkflowStartEventType
from collibra_core.models.named_resource_reference_impl import NamedResourceReferenceImpl
from collibra_core.models.navigation_statistics_entry import NavigationStatisticsEntry
from collibra_core.models.navigation_statistics_entry_paged_response import NavigationStatisticsEntryPagedResponse
from collibra_core.models.numeric_attribute import NumericAttribute
from collibra_core.models.numeric_attribute_all_of import NumericAttributeAllOf
from collibra_core.models.numeric_attribute_type import NumericAttributeType
from collibra_core.models.numeric_attribute_type_all_of import NumericAttributeTypeAllOf
from collibra_core.models.option_value import OptionValue
from collibra_core.models.paged_response import PagedResponse
from collibra_core.models.paged_response_activity import PagedResponseActivity
from collibra_core.models.paged_response_asset import PagedResponseAsset
from collibra_core.models.paged_response_asset_type import PagedResponseAssetType
from collibra_core.models.paged_response_attachment import PagedResponseAttachment
from collibra_core.models.paged_response_attribute_type import PagedResponseAttributeType
from collibra_core.models.paged_response_comment import PagedResponseComment
from collibra_core.models.paged_response_complex_relation_type import PagedResponseComplexRelationType
from collibra_core.models.paged_response_data_quality_rule import PagedResponseDataQualityRule
from collibra_core.models.paged_response_domain_type import PagedResponseDomainType
from collibra_core.models.paged_response_jdbc_driver import PagedResponseJdbcDriver
from collibra_core.models.paged_response_job import PagedResponseJob
from collibra_core.models.paged_response_mapping import PagedResponseMapping
from collibra_core.models.paged_response_navigation_statistics_entry import PagedResponseNavigationStatisticsEntry
from collibra_core.models.paged_response_rating import PagedResponseRating
from collibra_core.models.paged_response_relation_type import PagedResponseRelationType
from collibra_core.models.paged_response_responsibility import PagedResponseResponsibility
from collibra_core.models.paged_response_role import PagedResponseRole
from collibra_core.models.paged_response_scope import PagedResponseScope
from collibra_core.models.paged_response_status import PagedResponseStatus
from collibra_core.models.paged_response_tag import PagedResponseTag
from collibra_core.models.paged_response_user import PagedResponseUser
from collibra_core.models.paged_response_user_group import PagedResponseUserGroup
from collibra_core.models.paged_response_validation_result import PagedResponseValidationResult
from collibra_core.models.paged_response_view_permission import PagedResponseViewPermission
from collibra_core.models.paged_response_workflow_definition import PagedResponseWorkflowDefinition
from collibra_core.models.paged_response_workflow_instance import PagedResponseWorkflowInstance
from collibra_core.models.paged_response_workflow_task import PagedResponseWorkflowTask
from collibra_core.models.phone_number import PhoneNumber
from collibra_core.models.rating import Rating
from collibra_core.models.ratings_paged_response import RatingsPagedResponse
from collibra_core.models.related_asset_id import RelatedAssetId
from collibra_core.models.related_asset_reference import RelatedAssetReference
from collibra_core.models.relation_impl import RelationImpl
from collibra_core.models.relation_paged_response import RelationPagedResponse
from collibra_core.models.relation_trace_entry_impl import RelationTraceEntryImpl
from collibra_core.models.relation_trace_entry_request import RelationTraceEntryRequest
from collibra_core.models.relation_trace_impl import RelationTraceImpl
from collibra_core.models.relation_type_impl import RelationTypeImpl
from collibra_core.models.relation_type_paged_response import RelationTypePagedResponse
from collibra_core.models.remove_asset_tags_request import RemoveAssetTagsRequest
from collibra_core.models.remove_user_from_user_groups_request import RemoveUserFromUserGroupsRequest
from collibra_core.models.remove_users_from_user_group_request import RemoveUsersFromUserGroupRequest
from collibra_core.models.resource_reference import ResourceReference
from collibra_core.models.responsibility_impl import ResponsibilityImpl
from collibra_core.models.role_impl import RoleImpl
from collibra_core.models.scope_impl import ScopeImpl
from collibra_core.models.scope_paged_response import ScopePagedResponse
from collibra_core.models.script_attribute import ScriptAttribute
from collibra_core.models.script_attribute_all_of import ScriptAttributeAllOf
from collibra_core.models.script_attribute_type import ScriptAttributeType
from collibra_core.models.script_attribute_type_all_of import ScriptAttributeTypeAllOf
from collibra_core.models.set_asset_attributes_request import SetAssetAttributesRequest
from collibra_core.models.set_asset_relations_request import SetAssetRelationsRequest
from collibra_core.models.set_asset_responsibilities_request import SetAssetResponsibilitiesRequest
from collibra_core.models.set_asset_tags_request import SetAssetTagsRequest
from collibra_core.models.set_user_groups_for_user_request import SetUserGroupsForUserRequest
from collibra_core.models.single_value_list_attribute import SingleValueListAttribute
from collibra_core.models.single_value_list_attribute_all_of import SingleValueListAttributeAllOf
from collibra_core.models.single_value_list_attribute_type import SingleValueListAttributeType
from collibra_core.models.solution_info import SolutionInfo
from collibra_core.models.start_form_data_impl import StartFormDataImpl
from collibra_core.models.start_workflow_instances_request import StartWorkflowInstancesRequest
from collibra_core.models.status_impl import StatusImpl
from collibra_core.models.status_paged_response import StatusPagedResponse
from collibra_core.models.string_attribute import StringAttribute
from collibra_core.models.string_attribute_type import StringAttributeType
from collibra_core.models.string_attribute_type_all_of import StringAttributeTypeAllOf
from collibra_core.models.symbol_data_impl import SymbolDataImpl
from collibra_core.models.tag import Tag
from collibra_core.models.tag_paged_response import TagPagedResponse
from collibra_core.models.task_form_data import TaskFormData
from collibra_core.models.user import User
from collibra_core.models.user_group_impl import UserGroupImpl
from collibra_core.models.user_group_paged_response import UserGroupPagedResponse
from collibra_core.models.user_paged_response import UserPagedResponse
from collibra_core.models.user_permissions import UserPermissions
from collibra_core.models.user_reference_impl import UserReferenceImpl
from collibra_core.models.validate_in_job_request import ValidateInJobRequest
from collibra_core.models.validation_result_impl import ValidationResultImpl
from collibra_core.models.validation_result_paged_response import ValidationResultPagedResponse
from collibra_core.models.view_permission_impl import ViewPermissionImpl
from collibra_core.models.website import Website
from collibra_core.models.workflow_definition_impl import WorkflowDefinitionImpl
from collibra_core.models.workflow_definition_paged_response import WorkflowDefinitionPagedResponse
from collibra_core.models.workflow_definition_reference import WorkflowDefinitionReference
from collibra_core.models.workflow_instance import WorkflowInstance
from collibra_core.models.workflow_task import WorkflowTask
from collibra_core.models.workflow_task_paged_response import WorkflowTaskPagedResponse




# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from collibra_core.configuration import Configuration


class AddRoleRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'name': 'str',
        '_global': 'bool',
        'description': 'str',
        'permissions': 'list[str]'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        '_global': 'global',
        'description': 'description',
        'permissions': 'permissions'
    }

    def __init__(self, id=None, name=None, _global=None, description=None, permissions=None, local_vars_configuration=None):  # noqa: E501
        """AddRoleRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._name = None
        self.__global = None
        self._description = None
        self._permissions = None
        self.discriminator = None

        if id is not None:
            self.id = id
        self.name = name
        if _global is not None:
            self._global = _global
        if description is not None:
            self.description = description
        if permissions is not None:
            self.permissions = permissions

    @property
    def id(self):
        """Gets the id of this AddRoleRequest.  # noqa: E501

        The ID of the new role. Should be unique within all roles<br/><p><br/>It should have a format of universally unique identifier (UUID) and should not start<br/>with <code>00000000-0000-0000-</code> which is a reserved prefix.  # noqa: E501

        :return: The id of this AddRoleRequest.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this AddRoleRequest.

        The ID of the new role. Should be unique within all roles<br/><p><br/>It should have a format of universally unique identifier (UUID) and should not start<br/>with <code>00000000-0000-0000-</code> which is a reserved prefix.  # noqa: E501

        :param id: The id of this AddRoleRequest.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this AddRoleRequest.  # noqa: E501

        The name of the new role. Should be unique within all roles.  # noqa: E501

        :return: The name of this AddRoleRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AddRoleRequest.

        The name of the new role. Should be unique within all roles.  # noqa: E501

        :param name: The name of this AddRoleRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) > 255):
            raise ValueError("Invalid value for `name`, length must be less than or equal to `255`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) < 1):
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `1`")  # noqa: E501

        self._name = name

    @property
    def _global(self):
        """Gets the _global of this AddRoleRequest.  # noqa: E501

        Whether the role should be a global or resource role.  # noqa: E501

        :return: The _global of this AddRoleRequest.  # noqa: E501
        :rtype: bool
        """
        return self.__global

    @_global.setter
    def _global(self, _global):
        """Sets the _global of this AddRoleRequest.

        Whether the role should be a global or resource role.  # noqa: E501

        :param _global: The _global of this AddRoleRequest.  # noqa: E501
        :type: bool
        """

        self.__global = _global

    @property
    def description(self):
        """Gets the description of this AddRoleRequest.  # noqa: E501

        The description of the role.  # noqa: E501

        :return: The description of this AddRoleRequest.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this AddRoleRequest.

        The description of the role.  # noqa: E501

        :param description: The description of this AddRoleRequest.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def permissions(self):
        """Gets the permissions of this AddRoleRequest.  # noqa: E501

        The permissions to be granted for this role.  # noqa: E501

        :return: The permissions of this AddRoleRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._permissions

    @permissions.setter
    def permissions(self, permissions):
        """Sets the permissions of this AddRoleRequest.

        The permissions to be granted for this role.  # noqa: E501

        :param permissions: The permissions of this AddRoleRequest.  # noqa: E501
        :type: list[str]
        """
        allowed_values = ["EDGE", "EDGE_SITE_CONNECT", "EDGE_SITE_MANAGE", "EDGE_SITE_ADMINISTER", "EDGE_INTEGRATION_CAPABILITY_MANAGE", "EDGE_VIEW_CONNECTIONS_AND_CAPABILITIES", "EDGE_VIEW_LOGS", "ASSET_GRID_ADMINISTRATION", "ATTACHMENT_ADD", "ATTACHMENT_CHANGE", "ATTACHMENT_REMOVE", "COMMENT_ADD", "COMMENT_CHANGE", "COMMENT_REMOVE", "RATING_ADD", "RATING_CHANGE", "RATING_REMOVE", "COMMUNITY_ADD", "COMMUNITY_CHANGE", "COMMUNITY_REMOVE", "COMMUNITY_CONFIGURE_EXTERNAL_SYSTEM", "COMMUNITY_RESPONSIBILITY_ADD", "COMMUNITY_RESPONSIBILITY_CHANGE", "COMMUNITY_RESPONSIBILITY_REMOVE", "DOMAIN_ADD", "DOMAIN_CHANGE", "DOMAIN_REMOVE", "DOMAIN_RESPONSIBILITY_ADD", "DOMAIN_RESPONSIBILITY_CHANGE", "DOMAIN_RESPONSIBILITY_REMOVE", "WORKFLOW_MANAGE", "WORKFLOW_DESIGNER_ACCESS", "ASSET_ADD", "ASSET_CHANGE", "ASSET_REMOVE", "ASSET_STATUS_CHANGE", "ASSET_TYPE_CHANGE", "ASSET_TAG_CHANGE", "ASSET_ATTRIBUTE_ADD", "ASSET_ATTRIBUTE_CHANGE", "ASSET_ATTRIBUTE_REMOVE", "ASSET_RESPONSIBILITY_ADD", "ASSET_RESPONSIBILITY_CHANGE", "ASSET_RESPONSIBILITY_REMOVE", "VIEW_PERMISSIONS_CHANGE", "BUSINESS_SEMANTICS_GLOSSARY", "REFERENCE_DATA_MANAGER", "DATA_STEWARDSHIP_MANAGER", "SYSTEM_ADMINISTRATION", "USER_ADMINISTRATION", "WORKFLOW_ADMINISTRATION", "DATA_HELPDESK", "POLICY_MANAGER", "DATA_DICTIONARY", "CATALOG", "WORKFLOW_MANAGE_ALL", "WORKFLOW_MESSAGE_EVENTS_USE", "VIEW_PERMISSIONS_VIEW_ALL", "VIEW_MANAGE", "VIEW_SHARE", "VIEW_MANAGE_ALL", "ADVANCED_DATA_TYPE_ADD", "ADVANCED_DATA_TYPE_EDIT", "ADVANCED_DATA_TYPE_REMOVE", "TAGS_VIEW", "TAGS_MANAGE", "VALIDATION_EXECUTION", "ACCESS_DATA", "VIEW_SAMPLES", "RELATION_TYPE_ADD", "RELATION_TYPE_REMOVE", "RELATION_TYPE_CHANGE", "REGISTER_PROFILING_INFORMATION", "REPORTING_DOWNLOAD_INSIGHTS_DATA", "REPORTING_VIEW_INSIGHTS_REPORTS", "INSIGHTS_VIEW", "INSIGHTS_SUMMARY", "TECHNICAL_LINEAGE", "LOGS_VIEW", "RESOURCE_MANAGE_ALL", "CONFIGURATION_VIEW", "CONFIGURATION_EDIT", "BACKSTORE_VIEW", "BACKSTORE_EDIT", "ASSESSMENTS", "METADATA_LAKE", "PROTECT", "PROTECT_EDIT", "PROTECT_ADMINISTRATION", "PRIVACY"]  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                not set(permissions).issubset(set(allowed_values))):  # noqa: E501
            raise ValueError(
                "Invalid values for `permissions` [{0}], must be a subset of [{1}]"  # noqa: E501
                .format(", ".join(map(str, set(permissions) - set(allowed_values))),  # noqa: E501
                        ", ".join(map(str, allowed_values)))
            )

        self._permissions = permissions

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AddRoleRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AddRoleRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from collibra_core.configuration import Configuration


class CompleteWorkflowTasksRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'task_ids': 'list[str]',
        'form_properties': 'dict(str, str)',
        'guest_user_id': 'str'
    }

    attribute_map = {
        'task_ids': 'taskIds',
        'form_properties': 'formProperties',
        'guest_user_id': 'guestUserId'
    }

    def __init__(self, task_ids=None, form_properties=None, guest_user_id=None, local_vars_configuration=None):  # noqa: E501
        """CompleteWorkflowTasksRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._task_ids = None
        self._form_properties = None
        self._guest_user_id = None
        self.discriminator = None

        self.task_ids = task_ids
        if form_properties is not None:
            self.form_properties = form_properties
        if guest_user_id is not None:
            self.guest_user_id = guest_user_id

    @property
    def task_ids(self):
        """Gets the task_ids of this CompleteWorkflowTasksRequest.  # noqa: E501

        The list of IDs for tasks that should be completed.  # noqa: E501

        :return: The task_ids of this CompleteWorkflowTasksRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._task_ids

    @task_ids.setter
    def task_ids(self, task_ids):
        """Sets the task_ids of this CompleteWorkflowTasksRequest.

        The list of IDs for tasks that should be completed.  # noqa: E501

        :param task_ids: The task_ids of this CompleteWorkflowTasksRequest.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and task_ids is None:  # noqa: E501
            raise ValueError("Invalid value for `task_ids`, must not be `None`")  # noqa: E501

        self._task_ids = task_ids

    @property
    def form_properties(self):
        """Gets the form_properties of this CompleteWorkflowTasksRequest.  # noqa: E501

        The form properties for the workflow tasks to be completed.  # noqa: E501

        :return: The form_properties of this CompleteWorkflowTasksRequest.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._form_properties

    @form_properties.setter
    def form_properties(self, form_properties):
        """Sets the form_properties of this CompleteWorkflowTasksRequest.

        The form properties for the workflow tasks to be completed.  # noqa: E501

        :param form_properties: The form_properties of this CompleteWorkflowTasksRequest.  # noqa: E501
        :type: dict(str, str)
        """

        self._form_properties = form_properties

    @property
    def guest_user_id(self):
        """Gets the guest_user_id of this CompleteWorkflowTasksRequest.  # noqa: E501

        The ID of the guest user.  # noqa: E501

        :return: The guest_user_id of this CompleteWorkflowTasksRequest.  # noqa: E501
        :rtype: str
        """
        return self._guest_user_id

    @guest_user_id.setter
    def guest_user_id(self, guest_user_id):
        """Sets the guest_user_id of this CompleteWorkflowTasksRequest.

        The ID of the guest user.  # noqa: E501

        :param guest_user_id: The guest_user_id of this CompleteWorkflowTasksRequest.  # noqa: E501
        :type: str
        """

        self._guest_user_id = guest_user_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CompleteWorkflowTasksRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CompleteWorkflowTasksRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


from setuptools import setup, find_packages  # noqa: H301

NAME = "collibra-core"
VERSION = "2.0.0-5"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil"]

setup(
    name=NAME,
    version=VERSION,
    description="Collibra Data Governance Center Core API",
    author="OpenAPI Generator community",
    author_email="team@openapitools.org",
    url="",
    keywords=["OpenAPI", "OpenAPI-Generator", "Collibra Data Governance Center Core API"],
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    long_description="""\
    &lt;p&gt;The Core REST API allows you to create your own integrations with Collibra Data Governance Center.&lt;/p&gt;&lt;p&gt;&lt;i&gt;Create custom applications to help users get access to the right data.&lt;/i&gt;&lt;/p&gt;  # noqa: E501
    """
)



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from collibra_core.api_client import ApiClient
from collibra_core.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class StatusesApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def add_status(self, **kwargs):  # noqa: E501
        """Adds a new Status.  # noqa: E501

        Adds a new Status.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_status(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AddStatusRequest add_status_request:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: StatusImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.add_status_with_http_info(**kwargs)  # noqa: E501

    def add_status_with_http_info(self, **kwargs):  # noqa: E501
        """Adds a new Status.  # noqa: E501

        Adds a new Status.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_status_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AddStatusRequest add_status_request:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(StatusImpl, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'add_status_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_status" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'add_status_request' in local_var_params:
            body_params = local_var_params['add_status_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/statuses', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='StatusImpl',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def add_statuses(self, **kwargs):  # noqa: E501
        """Adds multiple statuses in one go.  # noqa: E501

        Adds multiple statuses in one go.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_statuses(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[AddStatusRequest] add_status_request:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[StatusImpl]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.add_statuses_with_http_info(**kwargs)  # noqa: E501

    def add_statuses_with_http_info(self, **kwargs):  # noqa: E501
        """Adds multiple statuses in one go.  # noqa: E501

        Adds multiple statuses in one go.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_statuses_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[AddStatusRequest] add_status_request:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[StatusImpl], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'add_status_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_statuses" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'add_status_request' in local_var_params:
            body_params = local_var_params['add_status_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/statuses/bulk', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[StatusImpl]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def change_status(self, status_id, **kwargs):  # noqa: E501
        """Changes the status with the information that is present in the request.  # noqa: E501

        Changes the status with the information that is present in the request. Only properties that are specified in this request and have not <code>null</code> values are updated. All other properties are ignored.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_status(status_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str status_id: The unique identifier of the status. (required)
        :param ChangeStatusRequest change_status_request:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: StatusImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.change_status_with_http_info(status_id, **kwargs)  # noqa: E501

    def change_status_with_http_info(self, status_id, **kwargs):  # noqa: E501
        """Changes the status with the information that is present in the request.  # noqa: E501

        Changes the status with the information that is present in the request. Only properties that are specified in this request and have not <code>null</code> values are updated. All other properties are ignored.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_status_with_http_info(status_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str status_id: The unique identifier of the status. (required)
        :param ChangeStatusRequest change_status_request:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(StatusImpl, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'status_id',
            'change_status_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method change_status" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'status_id' is set
        if self.api_client.client_side_validation and ('status_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['status_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `status_id` when calling `change_status`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'status_id' in local_var_params:
            path_params['statusId'] = local_var_params['status_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'change_status_request' in local_var_params:
            body_params = local_var_params['change_status_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/statuses/{statusId}', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='StatusImpl',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def change_statuses(self, **kwargs):  # noqa: E501
        """Changes multiple statuses in one go.  # noqa: E501

        Changes multiple statuses in one go.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_statuses(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[ChangeStatusRequest] change_status_request:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[StatusImpl]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.change_statuses_with_http_info(**kwargs)  # noqa: E501

    def change_statuses_with_http_info(self, **kwargs):  # noqa: E501
        """Changes multiple statuses in one go.  # noqa: E501

        Changes multiple statuses in one go.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_statuses_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[ChangeStatusRequest] change_status_request:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[StatusImpl], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'change_status_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method change_statuses" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'change_status_request' in local_var_params:
            body_params = local_var_params['change_status_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/statuses/bulk', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[StatusImpl]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def find_statuses(self, **kwargs):  # noqa: E501
        """Returns statuses matching the given search criteria.  # noqa: E501

        Returns statuses matching the given search criteria. Only parameters that are specified in this request and have not <code>null</code> values are used for filtering. All other parameters are ignored. The returned statuses satisfy all constraints that are specified in this search criteria. By default a result containing 1000 statuses is returned.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_statuses(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int offset: The first result to retrieve. If not set (offset = <code>0</code>), results will be retrieved starting from row <code>0</code>.
        :param int limit: The maximum number of results to retrieve. If not set (limit = <code>0</code>), the default limit will be used.
        :param int count_limit: Allows to limit the number of elements that will be counted. -1 will count everything and 0 will cause the count to be skipped
        :param str name: The name of the Status to search for.
        :param str name_match_mode: The match mode used to compare <code>name</code>. If the match mode is <code>EXACT</code> the search is case-sensitive, otherwise the search is case-insensitive.
        :param str description: The description of the Status to search for.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: StatusPagedResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.find_statuses_with_http_info(**kwargs)  # noqa: E501

    def find_statuses_with_http_info(self, **kwargs):  # noqa: E501
        """Returns statuses matching the given search criteria.  # noqa: E501

        Returns statuses matching the given search criteria. Only parameters that are specified in this request and have not <code>null</code> values are used for filtering. All other parameters are ignored. The returned statuses satisfy all constraints that are specified in this search criteria. By default a result containing 1000 statuses is returned.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_statuses_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int offset: The first result to retrieve. If not set (offset = <code>0</code>), results will be retrieved starting from row <code>0</code>.
        :param int limit: The maximum number of results to retrieve. If not set (limit = <code>0</code>), the default limit will be used.
        :param int count_limit: Allows to limit the number of elements that will be counted. -1 will count everything and 0 will cause the count to be skipped
        :param str name: The name of the Status to search for.
        :param str name_match_mode: The match mode used to compare <code>name</code>. If the match mode is <code>EXACT</code> the search is case-sensitive, otherwise the search is case-insensitive.
        :param str description: The description of the Status to search for.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(StatusPagedResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'offset',
            'limit',
            'count_limit',
            'name',
            'name_match_mode',
            'description'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method find_statuses" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'offset' in local_var_params and local_var_params['offset'] is not None:  # noqa: E501
            query_params.append(('offset', local_var_params['offset']))  # noqa: E501
        if 'limit' in local_var_params and local_var_params['limit'] is not None:  # noqa: E501
            query_params.append(('limit', local_var_params['limit']))  # noqa: E501
        if 'count_limit' in local_var_params and local_var_params['count_limit'] is not None:  # noqa: E501
            query_params.append(('countLimit', local_var_params['count_limit']))  # noqa: E501
        if 'name' in local_var_params and local_var_params['name'] is not None:  # noqa: E501
            query_params.append(('name', local_var_params['name']))  # noqa: E501
        if 'name_match_mode' in local_var_params and local_var_params['name_match_mode'] is not None:  # noqa: E501
            query_params.append(('nameMatchMode', local_var_params['name_match_mode']))  # noqa: E501
        if 'description' in local_var_params and local_var_params['description'] is not None:  # noqa: E501
            query_params.append(('description', local_var_params['description']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/statuses', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='StatusPagedResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_status(self, status_id, **kwargs):  # noqa: E501
        """Returns the Status identified by the given id.  # noqa: E501

        Returns the Status identified by the given id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_status(status_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str status_id: The <code>id</code> of the Status (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: StatusImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_status_with_http_info(status_id, **kwargs)  # noqa: E501

    def get_status_with_http_info(self, status_id, **kwargs):  # noqa: E501
        """Returns the Status identified by the given id.  # noqa: E501

        Returns the Status identified by the given id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_status_with_http_info(status_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str status_id: The <code>id</code> of the Status (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(StatusImpl, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'status_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_status" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'status_id' is set
        if self.api_client.client_side_validation and ('status_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['status_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `status_id` when calling `get_status`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'status_id' in local_var_params:
            path_params['statusId'] = local_var_params['status_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/statuses/{statusId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='StatusImpl',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_status_by_name(self, status_name, **kwargs):  # noqa: E501
        """Returns the Status identified by the given name.  # noqa: E501

        Returns the Status identified by the given name.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_status_by_name(status_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str status_name: The name that identifies the Status. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: StatusImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_status_by_name_with_http_info(status_name, **kwargs)  # noqa: E501

    def get_status_by_name_with_http_info(self, status_name, **kwargs):  # noqa: E501
        """Returns the Status identified by the given name.  # noqa: E501

        Returns the Status identified by the given name.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_status_by_name_with_http_info(status_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str status_name: The name that identifies the Status. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(StatusImpl, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'status_name'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_status_by_name" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'status_name' is set
        if self.api_client.client_side_validation and ('status_name' not in local_var_params or  # noqa: E501
                                                        local_var_params['status_name'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `status_name` when calling `get_status_by_name`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'status_name' in local_var_params:
            path_params['statusName'] = local_var_params['status_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/statuses/name/{statusName}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='StatusImpl',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remove_status(self, status_id, **kwargs):  # noqa: E501
        """Removes the Status identified by the given id.  # noqa: E501

        Removes the Status identified by the given id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_status(status_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str status_id: The <code>id</code> of the Status. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.remove_status_with_http_info(status_id, **kwargs)  # noqa: E501

    def remove_status_with_http_info(self, status_id, **kwargs):  # noqa: E501
        """Removes the Status identified by the given id.  # noqa: E501

        Removes the Status identified by the given id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_status_with_http_info(status_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str status_id: The <code>id</code> of the Status. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'status_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_status" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'status_id' is set
        if self.api_client.client_side_validation and ('status_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['status_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `status_id` when calling `remove_status`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'status_id' in local_var_params:
            path_params['statusId'] = local_var_params['status_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/statuses/{statusId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remove_statuses(self, **kwargs):  # noqa: E501
        """Removes multiple statuses.  # noqa: E501

        Removes multiple statuses.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_statuses(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] request_body: The indentifiers of the Statuses.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.remove_statuses_with_http_info(**kwargs)  # noqa: E501

    def remove_statuses_with_http_info(self, **kwargs):  # noqa: E501
        """Removes multiple statuses.  # noqa: E501

        Removes multiple statuses.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_statuses_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] request_body: The indentifiers of the Statuses.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'request_body'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_statuses" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'request_body' in local_var_params:
            body_params = local_var_params['request_body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/statuses/bulk', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import collibra_core
from collibra_core.api.scopes_api import ScopesApi  # noqa: E501
from collibra_core.rest import ApiException


class TestScopesApi(unittest.TestCase):
    """ScopesApi unit test stubs"""

    def setUp(self):
        self.api = collibra_core.api.scopes_api.ScopesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_scope(self):
        """Test case for add_scope

        Add scope  # noqa: E501
        """
        pass

    def test_change_scope(self):
        """Test case for change_scope

        Change scope  # noqa: E501
        """
        pass

    def test_get_all_scopes(self):
        """Test case for get_all_scopes

        Find scopes  # noqa: E501
        """
        pass

    def test_get_scope(self):
        """Test case for get_scope

        Get scope  # noqa: E501
        """
        pass

    def test_remove_scope(self):
        """Test case for remove_scope

        Remove scope  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
